@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -56,8 +56,8 @@ DropSiteWindow::DropSiteWindow()
 
 //! [constructor part2]
     dropArea = new DropArea;
-    connect(dropArea, SIGNAL(changed(const QMimeData *)),
-            this, SLOT(updateFormatsTable(const QMimeData *)));
+    connect(dropArea, SIGNAL(changed(const QMimeData*)),
+            this, SLOT(updateFormatsTable(const QMimeData*)));
 //! [constructor part2]
 
 //! [constructor part3]
@@ -119,10 +119,8 @@ void DropSiteWindow::updateFormatsTable(const QMimeData *mimeData)
             text = mimeData->html().simplified();
         } else if (format == "text/uri-list") {
             QList<QUrl> urlList = mimeData->urls();
-            for (int i = 0; i < urlList.size() && i < 32; ++i) {
-                QString url = urlList.at(i).path();
-                text.append(url + " ");
-            }
+            for (int i = 0; i < urlList.size() && i < 32; ++i)
+                text.append(urlList[i].toString() + " ");
         } else {
             QByteArray data = mimeData->data(format);
             for (int i = 0; i < data.size() && i < 32; ++i) {
