@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -49,8 +49,8 @@ AddressWidget::AddressWidget(QWidget *parent)
 {
     table = new TableModel(this);
     newAddressTab = new NewAddressTab(this);
-    connect(newAddressTab, SIGNAL(sendDetails(QString, QString)),
-        this, SLOT(addEntry(QString, QString))); 
+    connect(newAddressTab, SIGNAL(sendDetails(QString,QString)),
+        this, SLOT(addEntry(QString,QString))); 
 
     addTab(newAddressTab, "Address Book");    
 
@@ -104,7 +104,7 @@ void AddressWidget::editEntry()
     QModelIndex index, i;        
     QString name;
     QString address;
-    int row;
+    int row = -1;
 
     foreach (index, indexes) {
         row = proxy->mapToSource(index).row();
@@ -186,8 +186,8 @@ void AddressWidget::setupTabs()
         proxyModel->sort(0, Qt::AscendingOrder);
     
         connect(tableView->selectionModel(),
-            SIGNAL(selectionChanged(const QItemSelection &, const QItemSelection &)),
-            this, SIGNAL(selectionChanged(const QItemSelection &)));
+            SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+            this, SIGNAL(selectionChanged(QItemSelection)));
 
         addTab(tableView, str);
     }
