@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -79,14 +79,14 @@ MainWindow::MainWindow()
 
     QMenu *fileMenu = new QMenu(tr("&File"), this);
     QAction *openAction = fileMenu->addAction(tr("&Open..."));
-    openAction->setShortcut(QKeySequence(tr("Ctrl+O")));
+    openAction->setShortcuts(QKeySequence::Open);
 
     printAction = fileMenu->addAction(tr("&Print..."));
     printAction->setEnabled(false);
-    printAction->setShortcut(QKeySequence(tr("Ctrl+P")));
+    printAction->setShortcut(QKeySequence::Print);
 
     QAction *quitAction = fileMenu->addAction(tr("E&xit"));
-    quitAction->setShortcut(QKeySequence(tr("Ctrl+Q")));
+    quitAction->setShortcuts(QKeySequence::Quit);
 
     QMenu *helpMenu = new QMenu(tr("&Help"), this);
     QAction *aboutAction = helpMenu->addAction(tr("&About"));
