@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -208,7 +208,7 @@ void GLWidget::paintGL()
     for (int y = 0; y < 5; ++y) {
 	for (int x = 0; x < 5; ++x) {
 	    glTranslatef(2.0f, 0, 0);
-	    glColor4f(0.8, 0.8, 0.8, 1.0);
+	    glColor4f(0.8f, 0.8f, 0.8f, 1.0f);
 	    glDrawArrays(GL_QUADS, 0, 4);
 	}
  	glTranslatef(-10.0f, 2.0f, 0);
