@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -136,6 +136,7 @@ void GLWidget::draw()
     QPainter p(this); // used for text overlay
 
     // save the GL state set for QPainter
+    p.beginNativePainting();
     saveGLState();
 
     // render the 'bubbles.svg' file into our pbuffer
@@ -206,6 +207,7 @@ void GLWidget::draw()
 
     // restore the GL state that QPainter expects
     restoreGLState();
+    p.endNativePainting();
 
     // draw the overlayed text using QPainter
     p.setPen(QColor(197, 197, 197, 157));
