@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -53,7 +53,7 @@ MainWindow::MainWindow()
     QAction *openAction = fileMenu->addAction(tr("&Open..."));
     openAction->setShortcut(QKeySequence(tr("Ctrl+O")));
     QAction *quitAction = fileMenu->addAction(tr("E&xit"));
-    quitAction->setShortcut(QKeySequence(tr("Ctrl+Q")));
+    quitAction->setShortcuts(QKeySequence::Quit);
 
     menuBar()->addMenu(fileMenu);
 
@@ -103,8 +103,8 @@ MainWindow::MainWindow()
 
     connect(openAction, SIGNAL(triggered()), this, SLOT(openFile()));
     connect(quitAction, SIGNAL(triggered()), qApp, SLOT(quit()));
-    connect(rendererGroup, SIGNAL(triggered(QAction *)),
-            this, SLOT(setRenderer(QAction *)));
+    connect(rendererGroup, SIGNAL(triggered(QAction*)),
+            this, SLOT(setRenderer(QAction*)));
 
     setCentralWidget(m_view);
     setWindowTitle(tr("SVG Viewer"));
