@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -63,9 +63,14 @@ View::View(const QString &offices, const QString &images, QWidget *parent)
     QGraphicsPixmapItem *logo = scene->addPixmap(QPixmap(":/logo.png"));
     logo->setPos(30, 515);
 
+#ifndef Q_OS_SYMBIAN
     setMinimumSize(470, 620);
     setMaximumSize(470, 620);
-    setWindowTitle(tr("Offices World Wide"));
+#else
+    setDragMode(QGraphicsView::ScrollHandDrag);
+#endif
+
+   setWindowTitle(tr("Offices World Wide"));
 }
 //! [1]
 
@@ -126,16 +131,24 @@ void View::showInformation(ImageItem *image)
         window->raise();
         window->activateWindow();
     } else if (window && !window->isVisible()) {
+#ifndef Q_OS_SYMBIAN
         window->show();
+#else
+        window->showMaximized();
+#endif
     } else {
         InformationWindow *window;
         window = new InformationWindow(id, officeTable, this);
 
-        connect(window, SIGNAL(imageChanged(int, QString)),
-                this, SLOT(updateImage(int, QString)));
+        connect(window, SIGNAL(imageChanged(int,QString)),
+                this, SLOT(updateImage(int,QString)));
 
+#ifndef Q_OS_SYMBIAN
         window->move(pos() + QPoint(20, 40));
         window->show();
+#else
+        window->showMaximized();
+#endif
         informationWindows.append(window);
     }
 }
