@@ -1,6 +1,6 @@
 /****************************************************************************
 **
-** Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies).
+** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
 ** All rights reserved.
 ** Contact: Nokia Corporation (qt-info@nokia.com)
 **
@@ -293,7 +293,7 @@ void MainWindow::createImagesGroupBox()
 //! [23]
 
 //! [24]
-    connect(imagesTable, SIGNAL(itemChanged(QTableWidgetItem *)),
+    connect(imagesTable, SIGNAL(itemChanged(QTableWidgetItem*)),
 //! [24] //! [25]
             this, SLOT(changeIcon()));
 
@@ -369,7 +369,7 @@ void MainWindow::createActions()
             this, SLOT(removeAllImages()));
 
     exitAct = new QAction(tr("&Quit"), this);
-    exitAct->setShortcut(tr("Ctrl+Q"));
+    exitAct->setShortcuts(QKeySequence::Quit);
     connect(exitAct, SIGNAL(triggered()), this, SLOT(close()));
 
     styleActionGroup = new QActionGroup(this);
